@@ -7,7 +7,7 @@
 # (Consult LICENSE or http://www.boost.org/LICENSE_1_0.txt)
 
 from __future__ import absolute_import, print_function
-from faber.project import project, buildinfo
+from faber.project import init, project, buildinfo
 from faber.module import module as M
 from faber import logging
 from test.common import tempdir
@@ -34,6 +34,12 @@ def pytest_generate_tests(metafunc):
         metafunc.parametrize('compiler', compilers)
 
 
+@pytest.fixture(autouse=True)
+def session():
+    # reset global state
+    init()
+
+
 @pytest.fixture()
 def module():
     with tempdir() as root:
